@@ -18,7 +18,7 @@ def get_prepared_config(
         s3_signature_version,
         session_duration,
         sspi,
-        u2f_trigger_default,
+        username_password_command,
 ):
     """
     Prepares ADF configuration for login task.
@@ -40,7 +40,7 @@ def get_prepared_config(
     :param s3_signature_version: s3 signature version
     :param session_duration: AWS STS session duration (default 1 hour)
     :param sspi: Whether SSPI is enabled
-    :param u2f_trigger_default: Whether to also trigger the default authentication method when U2F is available
+    :param username_password_command: The command used to retrieve username and password information
     """
     def default_if_none(value, default):
         return value if value is not None else default
@@ -63,7 +63,7 @@ def get_prepared_config(
     )
     adfs_config.session_duration = default_if_none(session_duration, adfs_config.session_duration)
     adfs_config.sspi = default_if_none(sspi, adfs_config.sspi)
-    adfs_config.u2f_trigger_default = default_if_none(u2f_trigger_default, adfs_config.u2f_trigger_default)
+    adfs_config.username_password_command = default_if_none(username_password_command, adfs_config.username_password_command)
 
     return adfs_config
 
@@ -120,8 +120,8 @@ def create_adfs_default_config(profile):
     # Whether SSPI is enabled
     config.sspi = system() == "Windows"
 
-    # Whether to also trigger the default authentication method when U2F is available
-    config.u2f_trigger_default = True
+    # The command used to retrieve username and password information
+    config.username_password_command = None
 
     return config
 
@@ -188,9 +188,7 @@ def _load_adfs_config_from_stored_profile(adfs_config, profile):
         adfs_config.sspi = ast.literal_eval(config.get_or(
             profile, 'adfs_config.sspi',
             str(adfs_config.sspi)))
-        adfs_config.u2f_trigger_default = ast.literal_eval(config.get_or(
-            profile, 'adfs_config.u2f_trigger_default',
-            str(adfs_config.u2f_trigger_default)))
+        adfs_config.username_password_command = config.get_or(profile, 'adfs_config.username_password_command', adfs_config.username_password_command)
 
     if profile == 'default':
         load_from_config(adfs_config.aws_config_location, profile, load_config)
