@@ -1,27 +1,29 @@
-import ConfigParser
+import configparser
 
 import click
 
-from .prepare import adfs_config
+from os import environ
+from .prepare import create_adfs_default_config
 
 
 @click.command()
 @click.option(
     '--profile',
-    default=lambda: adfs_config.profile,
+    default=lambda: environ.get('AWS_DEFAULT_PROFILE', 'default'),
     help='AWS cli profile that will be removed'
 )
 def reset(profile):
     """
     removes stored profile
     """
+    adfs_config = create_adfs_default_config('default')
     _clear_credentials(adfs_config, profile)
     click.echo('Profile: \'{}\' has been wiped out'.format(profile))
 
 
 def _clear_credentials(config, profile):
     def store_config(config_location, storer):
-        config_file = ConfigParser.RawConfigParser()
+        config_file = configparser.RawConfigParser()
         config_file.read(config_location)
 
         if not config_file.has_section(profile):
